@@ -3,7 +3,10 @@
 
 namespace Icinga\Module\Cube\Controllers;
 
+use Icinga\Application\Modules\Module;
+use Icinga\Module\Cube\IcingaDb\IcingaDbHostStatusCube;
 use Icinga\Module\Cube\Ido\IdoHostStatusCube;
+use Icinga\Module\Cube\ProvidedHook\Icingadb\IcingadbSupport;
 use Icinga\Module\Cube\Web\IdoController;
 
 class HostsController extends IdoController
@@ -17,6 +20,10 @@ class HostsController extends IdoController
 
     protected function getCube()
     {
+        if (Module::exists('icingadb') && IcingadbSupport::useIcingaDbAsBackend()) {
+            return new IcingaDbHostStatusCube();
+        }
+
         return new IdoHostStatusCube();
     }
 }
