@@ -3,7 +3,10 @@
 
 namespace Icinga\Module\Cube\Controllers;
 
+use Icinga\Application\Modules\Module;
+use Icinga\Module\Cube\IcingaDb\IcingaDbServiceStatusCube;
 use Icinga\Module\Cube\Ido\IdoServiceStatusCube;
+use Icinga\Module\Cube\ProvidedHook\Icingadb\IcingadbSupport;
 use Icinga\Module\Cube\Web\IdoController;
 
 class ServicesController extends IdoController
@@ -17,6 +20,10 @@ class ServicesController extends IdoController
 
     protected function getCube()
     {
+        if (Module::exists('icingadb') && IcingadbSupport::useIcingaDbAsBackend()) {
+            return new IcingaDbServiceStatusCube();
+        }
+
         return new IdoServiceStatusCube();
     }
 }
