@@ -26,6 +26,11 @@ class CustomVarDimension implements Dimension
      */
     protected $varName;
 
+    /**
+     * @var string custom variable label
+     */
+    protected $varLabel;
+
     /**
      * @var bool Whether null values should be shown
      */
@@ -63,7 +68,45 @@ class CustomVarDimension implements Dimension
      */
     public function getName()
     {
-        return strtolower($this->varName);
+        return $this->varName;
+    }
+
+    /**
+     * @return string
+     */
+    public function getLabel()
+    {
+        return $this->varLabel ?: $this->getName();
+    }
+
+    /**
+     * Set the label
+     *
+     * @param string $label
+     * @return $this
+     */
+    public function setLabel($label)
+    {
+        $this->varLabel = $label;
+
+        return $this;
+    }
+
+    /**
+     * Add a label
+     *
+     * @param string $label
+     * @return $this
+     */
+    public function addLabel($label)
+    {
+        if ($this->varLabel === null) {
+            $this->setLabel($label);
+        } else {
+            $this->varLabel .= ' & ' . $label;
+        }
+
+        return $this;
     }
 
     public function getColumnExpression(Cube $cube)
@@ -96,9 +139,17 @@ class CustomVarDimension implements Dimension
         $name = $this->safeVarname($this->varName);
         /** @var $cube IdoCube */
         $alias = $cube->db()->quoteIdentifier(['c_' . $name]);
+
+        if ($cube->isPgsql()) {
+            $on = "LOWER($alias.varname) = ?";
+            $name = strtolower($name);
+        } else {
+            $on = $alias . '.varname = ? COLLATE latin1_general_ci';
+        }
+
         $cube->innerQuery()->joinLeft(
             array($alias => $cube->tableName('icinga_customvariablestatus')),
-            $cube->db()->quoteInto($alias . '.varname = ?', $name)
+            $cube->db()->quoteInto($on, $name)
             . ' AND ' . $alias . '.object_id = ' . $objectId,
             array()
         )->group($alias . '.varvalue');
