@@ -8,7 +8,6 @@ use Icinga\Authentication\Auth;
 use Icinga\Data\Filter\Filter;
 use Icinga\Exception\ConfigurationError;
 use Icinga\Exception\QueryException;
-use Icinga\Module\Cube\DbCube;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Util\GlobFilter;
 
@@ -50,7 +49,12 @@ abstract class IdoCube extends DbCube
     {
         $this->backend = $backend;
 
-        $this->setConnection($backend->getResource());
+        $resource = $backend->getResource();
+        $resource->getDbAdapter()
+            ->getConnection()
+            ->setAttribute(\PDO::ATTR_CASE, \PDO::CASE_NATURAL);
+
+        $this->setConnection($resource);
 
         return $this;
     }
