@@ -3,11 +3,14 @@
 
 namespace Icinga\Module\Cube\Ido;
 
+use Icinga\Module\Cube\CubeRenderer\HostStatusCubeRenderer;
+use Icinga\Module\Cube\Ido\DataView\Hoststatus;
+
 class IdoHostStatusCube extends IdoCube
 {
     public function getRenderer()
     {
-        return new IdoHostStatusCubeRenderer($this);
+        return new HostStatusCubeRenderer($this);
     }
 
     /**
@@ -16,9 +19,10 @@ class IdoHostStatusCube extends IdoCube
     public function getAvailableFactColumns()
     {
         return array(
-            'hosts_cnt'           => 'COUNT(*)',
-            'hosts_down'           => 'SUM(CASE WHEN hs.current_state = 1 THEN 1 ELSE 0 END)',
-            'hosts_unhandled_down' => 'SUM(CASE WHEN hs.current_state = 1'
+            'hosts_cnt'            => 'SUM(CASE WHEN hs.has_been_checked = 1 THEN 1 ELSE 0 END)',
+            'hosts_down'           => 'SUM(CASE WHEN hs.has_been_checked = 1 AND hs.current_state = 1'
+                . ' THEN 1 ELSE 0 END)',
+            'hosts_unhandled_down' => 'SUM(CASE WHEN hs.has_been_checked = 1 AND hs.current_state = 1'
                 . ' AND hs.problem_has_been_acknowledged = 0 AND hs.scheduled_downtime_depth = 0'
                 . ' THEN 1 ELSE 0 END)',
             'hosts_unreachable'           => 'SUM(CASE WHEN hs.current_state = 2 THEN 1 ELSE 0 END)',
@@ -28,6 +32,17 @@ class IdoHostStatusCube extends IdoCube
         );
     }
 
+    public function createDimension($name)
+    {
+        $this->registerAvailableDimensions();
+
+        if (isset($this->availableDimensions[$name])) {
+            return clone $this->availableDimensions[$name];
+        }
+
+        return new CustomVarDimension($name, CustomVarDimension::TYPE_HOST);
+    }
+
     /**
      * Add a specific named dimension
      *
@@ -40,7 +55,7 @@ class IdoHostStatusCube extends IdoCube
     public function addDimensionByName($name)
     {
         if (count($this->filterProtectedCustomvars(array($name))) === 1) {
-            $this->addDimension(new CustomVarDimension($name, CustomVarDimension::TYPE_HOST));
+            $this->addDimension($this->createDimension($name));
         }
 
         return $this;
@@ -83,7 +98,7 @@ class IdoHostStatusCube extends IdoCube
     {
         $this->requireBackend();
 
-        $view = $this->backend->select()->from('hoststatus');
+        $view = new Hoststatus($this->backend);
 
         $view->getQuery()->requireColumn('host_state');
 
